//----------------------------------------------------------------------------
//	SOURCE.JS
//		 
//----------------------------------------------------------------------------
//	SOURCE OBJECT DEFINITION -----------------------------------------------


		function Source(strElement) {
//----------------------------------------------------------------------------
// 		PURPOSE:	saves the original position of the source object.
//		NOTES:		A source object is created when an element on the page is clicked
//					and it implements the "doMouseDown()" function.  Any page element 
//					implements this function and be a source.
//		
//		PROPERTIES:	
//			sourceID	- taken from the html 'id' attriubte
//			sourceType	- string identifying the type of the source.  this 
//						  property is tested in the doMouseOver and doMouseDown methods.
//			x			- horizontal screen position relative to the element's offset parent.
//			y			- vertical screen position relative to the element's offset parent
//			offX		- combined horizontal distance of all the element's offset parents.
//			offY		- combined vertical distance of all the element's offset parents.
//			screenX		- (x + offX) - calculated absolute horizontal position of element.
//			screenY		- (y + offY) - calculated absolute vertical position of element.
//			
//----------------------------------------------------------------------------
			this.sourceID = strElement.id;
			
			// sourcetype attribute allows source object to identify itself to a target
			this.sourceType = strElement.getAttribute("SOURCETYPE");
			
			// save the position of the source in relation to its rendering parent
			this.x = strElement.style.pixelLeft;
			this.y = strElement.style.pixelTop;

			// calculate the offsets of any parent elements
			this.offX = 0;
			this.offY = 0;
			var elParent = document.all[this.sourceID].offsetParent;
			while (elParent.offsetParent != null)
			{
				this.offX += elParent.offsetLeft;
				this.offY += elParent.offsetTop;
				elParent = elParent.offsetParent;
			}
			this.screenX = this.x + this.offX;
			this.screenY = this.y + this.offY;
		}
